'use strict';

var _matchers = require('./matchers');

var visit = require(`unist-util-visit`);
var path = require('path');
var fs = require('fs');

var generateCodeSandboxUrl = require('./get-codesandbox-url').default;

module.exports = function (_ref) {
  var markdownAST = _ref.markdownAST;

  var _ref2 = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
      _ref2$classPrefix = _ref2.classPrefix,
      classPrefix = _ref2$classPrefix === undefined ? `language-` : _ref2$classPrefix;

  visit(markdownAST, `paragraph`, function (paragraph) {
    var validParapgraph = paragraph.children.length === 1 && paragraph.children[0].type === 'link';

    if (!validParapgraph) {
      return;
    }

    var node = paragraph.children[0];

    if (!node.url.startsWith('source:')) {
      return;
    }

    var sourcePath = (0, _matchers.getSourcePath)(node.url);
    var highlights = (0, _matchers.getHighlights)(node.url) || '';
    var codesandboxOptions = (0, _matchers.getOptions)(node.url) || '';

    var absoluteSourcePath = path.join(process.cwd(), sourcePath);

    if (!fs.existsSync(absoluteSourcePath)) {
      throw new Error(`Cannot find source in ${absoluteSourcePath}`);
    }

    var sourceCode = fs.readFileSync(absoluteSourcePath).toString().trim();

    var codeSandboxUrl = generateCodeSandboxUrl(sourcePath, (codesandboxOptions ? `&${codesandboxOptions}` : '') + (highlights ? `&highlights=${highlights}` : ''));

    node.url = codeSandboxUrl;

    paragraph.children.unshift({
      type: 'code',
      lang: path.extname(sourcePath).slice(1) + `{${highlights}}`,
      value: sourceCode
    });
  });
};